==> eslint-config-scalify-0.0.6.tgz: package/rules/code-style.js <==
// rules for defining coding style

module.exports =
{
	rules:
	{

		// Disallow or enforce spaces inside of single line blocks
		'array-bracket-spacing': [ 'warn', 'always' ],

		// Require Camelcase
		'camelcase': 'warn',

		// require or disallow trailing commas
		'comma-dangle': [ 'error', 'never' ],

		// enforce consistent brace style for blocks
		'brace-style': [ 'error', 'allman' ],

		// Enforces spacing around commas
		'comma-spacing': [ 'warn', {
			'before': false,
			'after': true
		} ],

		// require or disallow spacing between function identifiers and their invocations
		'func-call-spacing': [ 'warn', 'never' ],

		// Require or disallow named function expressions
		'func-names': 'off',

		// enforce the consistent use of either function declarations or expressions
		'func-style': [ 'warn', 'expression' ],

		// enforce consistent indentation
		'indent': [ 'warn', 'tab' ],

		// enforce the consistent use of either double or single quotes in JSX attributes
		'jsx-quotes': [ 'warn', 'prefer-single' ],

		// enforce consistent spacing before and after keywords
		'keyword-spacing': [ 'warn', {
			'before': true,
			'after': true
		} ],

		// enforce position of line comments
		'line-comment-position': [ 'warn',
			{
				'position': 'above'
			}
		],

		// require empty lines around comments
		'lines-around-comment': [ 'warn', {
			'afterBlockComment': true,
			'beforeLineComment': true
		} ],

		// enforce a maximum depth that blocks can be nested
		'max-depth': [ 'warn', 4 ],

		// enforce a maximum depth that callbacks can be nested
		'max-nested-callbacks': [ 'warn', 4 ],

		// enforce a maximum number of parameters in function definitions
		'max-params': [ 'warn', 4 ],

		// Enforce or disallow newlines between operands of ternary expressions
		'multiline-ternary': [ 'warn', 'always' ],

		// require constructor function names to begin with a capital letter
		'new-cap': [ 'warn', {
			'newIsCap': true,
			'capIsNew': true
		} ],

		// require parentheses when invoking a constructor with no arguments
		'new-parens': 'warn',

		// require or disallow an empty line after var declarations
		'newline-after-var': [ 'warn', 'always' ],

		// require an empty line before return statements
		'newline-before-return': 'warn',

		// disallow inline comments after code
		'no-inline-comments': 'warn',

		// disallow if statements as the only statement in else blocks
		'no-lonely-if': 'warn',

		// Disallow mixes of different operators (no-mixed-operators)
		'no-mixed-operators': 'warn',

		// disallow multiple empty lines
		'no-multiple-empty-lines': [ 'warn',
			{
				'max': 1
			}
		],

		// disallow negated conditions
		'no-negated-condition': 'warn',

		// disallow nested ternary expressions
		'no-nested-ternary': 'warn',

		// disallow trailing whitespace at the end of lines
		'no-trailing-spaces': 'off',

		// disallow ternary operators when simpler alternatives exist
		'no-unneeded-ternary': 'warn',

		// disallow whitespace before properties
		'no-whitespace-before-property': 'warn',

		// enforce consistent line breaks inside braces
		'object-curly-newline': 'off',

		// enforce placing object properties on separate lines
		'object-property-newline': 'warn',

		// require or disallow newlines around var declarations
		'one-var-declaration-per-line': [ 'warn', 'initializations' ],

		// require JSDoc comments
		'require-jsdoc': [ 'off', {
			'require': {
				'FunctionDeclaration': true,
				'MethodDefinition': true,
				'ClassDeclaration': true
			}
		} ],

		// enforce consistent spacing before function definition opening parenthesis
		'space-before-function-paren': [ 'warn', 'always' ],

		// enforce consistent spacing inside parentheses
		'space-in-parens': [ 'warn', 'always' ],

		// Require Spaces Around Infix Operators
		'space-infix-ops': 'warn',

		// Require or disallow spaces before/after unary operators
		'space-unary-ops': 'warn',

		// Require Regex Literals to be Wrapped
		'wrap-regex': 'warn'
	}
};

==> eslint-config-scalify-0.0.12.tgz: package/rules/code-style.js <==
// rules for defining coding style

module.exports =
{
	rules:
	{

		// Disallow or enforce spaces inside of single line blocks
		'array-bracket-spacing': [ 'warn', 'always' ],

		// Require Camelcase
		'camelcase': 'warn',

		// require or disallow trailing commas
		'comma-dangle': [ 'error', 'never' ],

		// enforce consistent brace style for blocks
		'brace-style': [ 'error', 'allman' ],

		// Enforces spacing around commas
		'comma-spacing': [ 'warn', {
			'before': false,
			'after': true
		} ],

		// require or disallow spacing between function identifiers and their invocations
		'func-call-spacing': [ 'warn', 'never' ],

		// Require or disallow named function expressions
		'func-names': 'off',

		// enforce the consistent use of either function declarations or expressions
		'func-style': [ 'warn', 'expression' ],

		// enforce consistent indentation
		'indent': [ 'warn', 'tab' ],

		// enforce consistent spacing before and after keywords
		'keyword-spacing': [ 'warn', {
			'before': true,
			'after': true
		} ],

		// enforce position of line comments
		'line-comment-position': [ 'warn',
			{
				'position': 'above'
			}
		],

		// require empty lines around comments
		'lines-around-comment': [ 'warn', {
			'afterBlockComment': false,
			'beforeLineComment': true
		} ],

		// enforce a maximum depth that blocks can be nested
		'max-depth': [ 'warn', 4 ],

		// enforce a maximum depth that callbacks can be nested
		'max-nested-callbacks': [ 'warn', 4 ],

		// enforce a maximum number of parameters in function definitions
		'max-params': [ 'warn', 4 ],

		// Enforce or disallow newlines between operands of ternary expressions
		'multiline-ternary': [ 'warn', 'always' ],

		// require constructor function names to begin with a capital letter
		'new-cap': [ 'warn', {
			'newIsCap': true,
			'capIsNew': true
		} ],

		// require parentheses when invoking a constructor with no arguments
		'new-parens': 'warn',

		// require a newline after each call in a method chain
		'newline-per-chained-call': 'warn',

		// require or disallow an empty line after var declarations
		'newline-after-var': [ 'warn', 'always' ],

		// require an empty line before return statements
		'newline-before-return': 'warn',

		// disallow inline comments after code
		'no-inline-comments': 'warn',

		// disallow if statements as the only statement in else blocks
		'no-lonely-if': 'warn',

		// Disallow mixes of different operators (no-mixed-operators)
		'no-mixed-operators': 'warn',

		// disallow multiple empty lines
		'no-multiple-empty-lines': [ 'warn',
			{
				'max': 1
			}
		],

		// disallow negated conditions
		'no-negated-condition': 'warn',

		// disallow nested ternary expressions
		'no-nested-ternary': 'warn',

		// disallow trailing whitespace at the end of lines
		'no-trailing-spaces': 'off',

		// disallow ternary operators when simpler alternatives exist
		'no-unneeded-ternary': 'warn',

		// disallow whitespace before properties
		'no-whitespace-before-property': 'warn',

		// enforce consistent line breaks inside braces
		'object-curly-newline': 'off',

		// enforce placing object properties on separate lines
		'object-property-newline': 'warn',

		// require or disallow newlines around var declarations
		'one-var-declaration-per-line': [ 'warn', 'initializations' ],

		// require JSDoc comments
		'require-jsdoc': [ 'error', {
			'require': {
				'FunctionDeclaration': true,
				'MethodDefinition': true,
				'ClassDeclaration': true
			}
		} ],

		// enforce consistent spacing before function definition opening parenthesis
		'space-before-function-paren': [ 'off', 'always' ],

		// enforce consistent spacing inside parentheses
		'space-in-parens': [ 'warn', 'always' ],

		// Require Spaces Around Infix Operators
		'space-infix-ops': 'warn',

		// Require or disallow spaces before/after unary operators
		'space-unary-ops': 'warn',

		// Require Regex Literals to be Wrapped
		'wrap-regex': 'warn'
	}
};
